==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AssigningPolarStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarStyleEventArgsDescription } from "./AssigningPolarStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningPolarStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningPolarStyleEventArgsDescriptionMetadata, _super);
    function AssigningPolarStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningPolarStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningPolarStyleEventArgsDescriptionMetadata.a == null) {
            AssigningPolarStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningPolarStyleEventArgsDescriptionMetadata.c(AssigningPolarStyleEventArgsDescriptionMetadata.a);
        }
        if (a.g(AssigningPolarStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AssigningPolarStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningPolarStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningPolarStyleEventArgsDescriptionMetadata.b(a);
        a.u("AssigningPolarStyleEventArgs", function () { return new AssigningPolarStyleEventArgsDescription(); });
        a.t("AssigningPolarStyleEventArgs", AssigningPolarStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarStyleEventArgsDescriptionMetadata, 'AssigningPolarStyleEventArgsDescriptionMetadata');
    AssigningPolarStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningPolarStyleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AssigningPolarStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningPolarStyleEventArgsDescription } from "./AssigningPolarStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningPolarStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningPolarStyleEventArgsDescriptionMetadata, _super);
    function AssigningPolarStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningPolarStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningPolarStyleEventArgsDescriptionMetadata.a == null) {
            AssigningPolarStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningPolarStyleEventArgsDescriptionMetadata.c(AssigningPolarStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningPolarStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningPolarStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningPolarStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningPolarStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningPolarStyleEventArgs", function () { return new AssigningPolarStyleEventArgsDescription(); });
        a.z("AssigningPolarStyleEventArgs", AssigningPolarStyleEventArgsDescriptionMetadata.a);
    };
    AssigningPolarStyleEventArgsDescriptionMetadata.$t = markType(AssigningPolarStyleEventArgsDescriptionMetadata, 'AssigningPolarStyleEventArgsDescriptionMetadata');
    AssigningPolarStyleEventArgsDescriptionMetadata.a = null;
    return AssigningPolarStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningPolarStyleEventArgsDescriptionMetadata };
